@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright 2001-2024 Zabbix SIA
 **
 ** Licensed under the Apache License, Version 2.0 (the "License");
 ** you may not use this file except in compliance with the License.
@@ -20,7 +20,6 @@ package dbconn
 import (
 	"context"
 	"database/sql"
-	"fmt"
 	"net/url"
 	"path/filepath"
 	"strconv"
@@ -218,7 +217,7 @@ func (c *ConnCollection) newConn(
 	)
 
 	connURI, err := uri.NewWithCreds(
-		conf.URI, conf.User, conf.Password, &uri.Defaults{Scheme: params.URIDefaults.Scheme},
+		conf.URI, conf.User, conf.Password, params.URIDefaults,
 	)
 	if err != nil {
 		return nil, errs.Wrap(err, "failed to set URI defaults")
@@ -229,12 +228,6 @@ func (c *ConnCollection) newConn(
 		return nil, errs.Wrap(err, "failed to parse URI")
 	}
 
-	if connURI.Port() == "" && connURI.Path() == "" {
-		u.Host = fmt.Sprintf("%s:%s", u.Hostname(), params.URIDefaults.Port)
-	}
-
-	u.Path = connURI.Path()
-
 	queryParams := u.Query()
 	queryParams.Add("app name", "Zabbix agent 2 MSSQL plugin")
 	queryParams.Add("keepAlive", strconv.Itoa(c.keepAlive))
