@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright 2001-2024 Zabbix SIA
 **
 ** Licensed under the Apache License, Version 2.0 (the "License");
 ** you may not use this file except in compliance with the License.
@@ -98,10 +98,9 @@ func (nuid *nullUniqueIdentifier) Scan(value any) error {
 }
 
 // Value implements the driver Valuer interface.
-func (nuid *nullUniqueIdentifier) Value() (driver.Value, error) {
+func (nuid nullUniqueIdentifier) Value() (driver.Value, error) {
 	if !nuid.valid {
-		// here nil is a valid return representing NULL value from DB
-		return nil, nil //nolint:nilnil
+		return nil, nil
 	}
 
 	// check that the underlying UUID is valid.
@@ -121,8 +120,7 @@ func (b nullBool) Value() (driver.Value, error) {
 	}
 
 	if valuer == nil {
-		// here nil is a valid return representing NULL value from DB
-		return nil, nil //nolint:nilnil
+		return nil, nil
 	}
 
 	v, ok := valuer.(bool)
@@ -131,10 +129,10 @@ func (b nullBool) Value() (driver.Value, error) {
 	}
 
 	if v {
-		return int64(1), nil
+		return 1, nil
 	}
 
-	return int64(0), nil
+	return 0, nil
 }
 
 // WithJSONResponse wraps a handler function, marshaling its response
