@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright 2001-2024 Zabbix SIA
 **
 ** Licensed under the Apache License, Version 2.0 (the "License");
 ** you may not use this file except in compliance with the License.
@@ -148,6 +148,7 @@ func Test_nullUniqueIdentifier_Scan(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -162,7 +163,6 @@ func Test_nullUniqueIdentifier_Scan(t *testing.T) {
 					err, tt.wantErr,
 				)
 			}
-
 			if diff := cmp.Diff(
 				tt.wantNUID, nuid,
 				cmp.AllowUnexported(nullUniqueIdentifier{}),
@@ -214,6 +214,7 @@ func Test_nullUniqueIdentifier_Value(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -254,13 +255,13 @@ func Test_nullBool_Value(t *testing.T) {
 		{
 			"+validTrue",
 			fields{NullBool: sql.NullBool{Bool: true, Valid: true}},
-			int64(1),
+			1,
 			false,
 		},
 		{
 			"+validFalse",
 			fields{NullBool: sql.NullBool{Bool: false, Valid: true}},
-			int64(0),
+			0,
 			false,
 		},
 		{
@@ -271,6 +272,7 @@ func Test_nullBool_Value(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -295,8 +297,6 @@ func Test_nullBool_Value(t *testing.T) {
 }
 
 func TestWithJSONResponse(t *testing.T) {
-	t.Parallel()
-
 	newHandlerFunc := func(handlerErr error, invalidJSON bool) HandlerFunc {
 		return func(
 			metricParams map[string]string, extraParams ...string,
@@ -330,6 +330,8 @@ func TestWithJSONResponse(t *testing.T) {
 		}
 	}
 
+	t.Parallel()
+
 	type args struct {
 		handler     HandlerFunc
 		params      map[string]string
@@ -383,6 +385,7 @@ func TestWithJSONResponse(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -547,6 +550,7 @@ func TestCustomQueries_Load(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -637,6 +641,7 @@ func TestCustomQueries_HandlerFunc(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -741,6 +746,7 @@ func TestQueryHandlerFunc(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -830,6 +836,7 @@ func TestVersionHandler(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -910,18 +917,7 @@ func Test_rowsToJSON(t *testing.T) {
 					AddRow("bool", true).
 					AddRow("nil", nil).
 					AddRow("bytes", []byte("abc")).
-					AddRow("time", now).
-					AddRow("valid bool", &nullBool{
-						NullBool: sql.NullBool{Bool: true, Valid: true},
-					}).
-					AddRow("null bool", &nullBool{}).
-					AddRow("valid uuid", &nullUniqueIdentifier{
-						uuid: &mssql.UniqueIdentifier{
-							1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 12, 13, 14, 15, 16,
-						},
-						valid: true,
-					}).
-					AddRow("null uuid", &nullUniqueIdentifier{valid: false}),
+					AddRow("time", now),
 			},
 			[]map[string]any{
 				{"type": wrapAny("int"), "val": wrapAny(int64(1))},
@@ -931,13 +927,6 @@ func Test_rowsToJSON(t *testing.T) {
 				{"type": wrapAny("nil"), "val": wrapAny(nil)},
 				{"type": wrapAny("bytes"), "val": wrapAny([]byte("abc"))},
 				{"type": wrapAny("time"), "val": wrapAny(now)},
-				{"type": wrapAny("valid bool"), "val": wrapAny(int64(1))},
-				{"type": wrapAny("null bool"), "val": wrapAny(nil)},
-				{
-					"type": wrapAny("valid uuid"),
-					"val":  wrapAny("01020304-0506-0708-090A-0C0D0E0F1000"),
-				},
-				{"type": wrapAny("null uuid"), "val": wrapAny(nil)},
 			},
 			false,
 		},
@@ -954,6 +943,7 @@ func Test_rowsToJSON(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
