@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright 2001-2024 Zabbix SIA
 **
 ** Licensed under the Apache License, Version 2.0 (the "License");
 ** you may not use this file except in compliance with the License.
@@ -76,6 +76,7 @@ func Test_mssqlPlugin_Start(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -90,8 +91,9 @@ func Test_mssqlPlugin_Start(t *testing.T) {
 
 			if diff := cmp.Diff(
 				tt.wantCons, p.conns,
-				cmp.AllowUnexported(dbconn.ConnCollection{}, sync.Mutex{}, mssqlPlugin{}),
-				cmpopts.IgnoreFields(dbconn.ConnCollection{}, "mu"),
+				cmp.AllowUnexported(
+					dbconn.ConnCollection{}, sync.Mutex{}, mssqlPlugin{},
+				),
 				cmpopts.IgnoreTypes(mssqlPlugin{}),
 			); diff != "" {
 				t.Fatalf("mssqlPlugin.Start() = %s", diff)
@@ -120,6 +122,7 @@ func Test_mssqlPlugin_Stop(t *testing.T) {
 		{"+valid", fields{conns: &dbconn.ConnCollection{}}},
 	}
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -295,6 +298,7 @@ func Test_mssqlPlugin_Export(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -335,6 +339,7 @@ func Test_mssqlPlugin_registerMetrics(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
